pub struct ConsoleStreamHandler { /* private fields */ }Expand description
Writes streaming output to stdout/stderr.
In normal mode, displays assistant text and tool invocations. In verbose mode, also displays tool results and session summary.
Implementations